@@ -25,6 +25,7 @@ require 'rmail'
 require 'feedparser'
 require 'feedparser/text-output'
 require 'feedparser/html-output'
+require 'feed2imap/version'
 require 'base64'
 require 'rmail'
 require 'digest/md5'
@@ -65,7 +66,7 @@ def item_to_mail(config, item, id, updated, from = 'Feed2Imap', inline_images =
   else
     message.header['Date'] = item.date.rfc2822
   end
-  message.header['X-Feed2Imap-Version'] = F2I_VERSION if defined?(F2I_VERSION)
+  message.header['X-Feed2Imap-Version'] = Feed2Imap::VERSION
   message.header['Message-Id'] = id
   message.header['X-F2IStatus'] = "Updated" if updated
   # treat subject. Might need MIME encoding.
@@ -100,24 +101,8 @@ def item_to_mail(config, item, id, updated, from = 'Feed2Imap', inline_images =
       # $2 contains url, $3 the image name, $4 the image extension
       begin
         fetcher = HTTPFetcher.new
-        image = Base64.encode64(fetcher.fetch($2, Time.at(0)).chomp) + "\n"
-        cid = "#{Digest::MD5.hexdigest($2)}@#{config.hostname}"
-        if not cids.include?(cid)
-          cids << cid
-          imgpart = RMail::Message.new
-          imgpart.header.set('Content-ID', "<#{cid}>")
-          type = $4
-          type = 'jpeg' if type.downcase == 'jpg' # hack hack hack
-          imgpart.header.set('Content-Type', "image/#{type}", 'name' => $3)
-          imgpart.header.set('Content-Disposition', 'attachment', 'filename' => $3)
-          imgpart.header.set('Content-Transfer-Encoding', 'base64')
-          imgpart.body = image
-          imgs << imgpart
-        end
-        # now to specify what to replace with
-        newtag = "#{$1}src=\"cid:#{cid}\"#{$5}"
-        #print "#{cid}: Replacing '#{$&}' with '#{newtag}'...\n"
-        newtag
+        image = Base64.encode64(fetcher.fetch($2, Time.at(0)).chomp)
+        "#{$1}src=\"data:image/#{$4};base64,#{image}\"#{$5}"
       rescue
         #print "Error while fetching image #{$2}: #{$!}...\n"
         $& # don't modify on exception
